#Region "Copyright (C) 2012 James D Westoby"

' Copyright (C) 2012 James D Westoby
'
'  This Program is free software you can redistribute it and/or modify
'  it under the terms of the GNU General Public License as published by
'  the Free Software Foundation either version 2, or (at your option)
'  any later version.
'   
'  This Program is distributed in the hope that it will be useful,
'  but WITHOUT ANY WARRANTY without even the implied warranty of
'  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
'  GNU General Public License for more details.
'   
'  You should have received a copy of the GNU General Public License
'  along with GNU Make see the file COPYING.  If not, write to
'  the Free Software Foundation, 675 Mass Ave, Cambridge, MA 02139, USA. 
'  http:'www.gnu.org/copyleft/gpl.html

#End Region


Imports System
Imports System.Diagnostics.Process

Imports MediaPortal.GUI.Library
Imports MediaPortal.Util
Imports MediaPortal.Player



Namespace InternetRadioPlugin
    Public Class InternetRadioPlugin
        Inherits GUIWindow
        Implements ISetupForm

        <SkinControl(11)> Protected buttonOff As GUIButtonControl = Nothing
        <SkinControl(12)> Protected buttonNew As GUIButtonControl = Nothing
        <SkinControl(21)> Protected listStations As GUIListControl = Nothing

        Private Declare Function FindWindow Lib "user32" Alias _
            "FindWindow" (ByVal lpClassName As String, ByVal lpWindowName As String) As IntPtr

        Private Declare Function GetForegroundWindow Lib "user32" Alias _
            "GetForegroundWindow" () As IntPtr

        Private Declare Function SetForegroundWindow Lib "user32" Alias _
            "SetForegroundWindow" (ByVal hWnd As IntPtr) As Boolean



        Private myCommon As InternetRadioCommon = Nothing
        Private myMP As IntPtr = IntPtr.Zero

        Private myPlayer As New RadioPlayer


#Region "ISetupFormMembers"

        Public Function Author1() As String Implements MediaPortal.GUI.Library.ISetupForm.Author
            Return ("James D Westoby")
        End Function


        Public Function Description() As String Implements MediaPortal.GUI.Library.ISetupForm.Description
            Return ("Internet Radio Plugin")
        End Function


        Public Function CanEnable1() As Boolean Implements MediaPortal.GUI.Library.ISetupForm.CanEnable
            Return (True)
        End Function


        Public Function DefaultEnabled() As Boolean Implements MediaPortal.GUI.Library.ISetupForm.DefaultEnabled
            Return (True)
        End Function


        Public Function GetHome(ByRef strButtonText As String, ByRef strButtonImage As String, ByRef strButtonImageFocus As String, ByRef strPictureImage As String) As Boolean Implements MediaPortal.GUI.Library.ISetupForm.GetHome
            strButtonText = PluginName()
            strButtonImage = String.Empty
            strButtonImageFocus = String.Empty
            strButtonImage = String.Empty
            strPictureImage = "hover_internetradio.png"
            Return (True)
        End Function


        Public Overrides Property GetID() As Integer
            Get
                Return (GetWindowId())
            End Get
            Set(ByVal value As Integer)
                'donothing
            End Set
        End Property


        Public Function GetWindowId() As Integer Implements MediaPortal.GUI.Library.ISetupForm.GetWindowId
            Return (InternetRadioCommon.MainForm)
        End Function


        Public Function HasSetup() As Boolean Implements MediaPortal.GUI.Library.ISetupForm.HasSetup
            Return (True)
        End Function


        Public Function PluginName() As String Implements MediaPortal.GUI.Library.ISetupForm.PluginName
            Return ("Internet Radio")
        End Function


        Public Sub ShowPlugin() Implements MediaPortal.GUI.Library.ISetupForm.ShowPlugin
            'configure inside MediaPortal
        End Sub

#End Region


#Region "InternetRadioPlugin class"

        Public Overrides Function Init() As Boolean
            myMP = GetMediaPortalWindowHandle()
            myCommon = New InternetRadioCommon(GetWindowId())
            Return (Load(GUIGraphicsContext.Skin & InternetRadioCommon.MainSkin))
        End Function


        Protected Overrides Sub OnClicked(ByVal controlId As Integer, ByVal control As GUIControl, ByVal actionType As MediaPortal.GUI.Library.Action.ActionType)
            If (control Is buttonOff) Then OnStop()
            If (control Is buttonNew) Then OnConfig(InternetRadioCommon.NewName)
            If (control Is listStations) Then OnPlay()

            MyBase.OnClicked(controlId, control, actionType)
        End Sub


        Protected Overrides Sub OnPageDestroy(ByVal NewWindowId As Integer)
            MyBase.OnPageDestroy(NewWindowId)       'and call the base class too
        End Sub


        Protected Overrides Sub OnPageLoad()
            buttonOff.Label = myCommon.Text("Off")
            buttonNew.Label = myCommon.Text("New")
            SetStationlist()
            MyBase.OnPageLoad()
        End Sub


        Protected Overrides Sub OnShowContextMenu()
            OnConfig(listStations.SelectedListItem.Label)
        End Sub

#End Region


#Region "Private Methods"

        Private Function GetMediaPortalWindowHandle() As IntPtr
            Dim i As IntPtr = GetForegroundWindow
            If (i <> IntPtr.Zero) Then Return (i)

            Dim p As System.Diagnostics.Process() = GetProcessesByName("MediaPortal")
            If (0 < p.Length) Then
                Return (p(0).MainWindowHandle)
            Else
                Return (FindWindow(vbNullString, "MediaPortal"))
            End If
            Return (IntPtr.Zero)
        End Function


        Private Sub OnConfig(ByRef Name As String)
            GUIWindowManager.ActivateWindow(InternetRadioCommon.ConfigForm, Name)
            SetStationList()
        End Sub


        Private Sub OnPlay()
            Dim n As String = listStations.SelectedListItem.Label
            Dim t As String = myCommon.Title(n)
            Dim u As String = myCommon.URL(n)
            myPlayer.StartPlay(n, t, u)
            If (myMP <> IntPtr.Zero) Then SetForegroundWindow(myMP)
            GUIWindowManager.ActivateWindow(GetWindowId())
        End Sub


        Private Sub OnStop()
            myPlayer.StopPlay()
            GUIWindowManager.ActivateWindow(GetWindowId())
        End Sub


        Private Sub SetStationList()
            listStations.Clear()

            myCommon.ConfigLoad()
            Dim m As Integer = myCommon.Count
            For i As Integer = 1 To m
                Dim n As New GUIListItem(myCommon.Name(i))
                listStations.Add(n)
            Next i

            'how many to show?
            If (9 < m) Then m = 10
            listStations.ItemsPerPage = m + 1
            listStations.DoUpdate()
        End Sub

#End Region

    End Class

End Namespace
